"""The product type for LAN Switch Interconnect."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.lan_switch_interconnect import (
    LanSwitchInterconnectBlock,
    LanSwitchInterconnectBlockInactive,
    LanSwitchInterconnectBlockProvisioning,
)


class LanSwitchInterconnectInactive(SubscriptionModel, is_base=True):
    """An LAN Switch Interconnect that is inactive."""

    lan_switch_interconnect: LanSwitchInterconnectBlockInactive


class LanSwitchInterconnectProvisioning(LanSwitchInterconnectInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """An LAN Switch Interconnect that is being provisioned."""

    lan_switch_interconnect: LanSwitchInterconnectBlockProvisioning


class LanSwitchInterconnect(LanSwitchInterconnectProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An LAN Switch Interconnect that is active."""

    lan_switch_interconnect: LanSwitchInterconnectBlock


class ImportedLanSwitchInterconnectInactive(SubscriptionModel, is_base=True):
    """An imported, inactive :term:`LAN` Switch Interconnect."""

    lan_switch_interconnect: LanSwitchInterconnectBlockInactive


class ImportedLanSwitchInterconnect(
    ImportedLanSwitchInterconnectInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported :term:`LAN` Switch Interconnect."""

    lan_switch_interconnect: LanSwitchInterconnectBlock
