"""Product type for a Layer 2 circuit."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.layer_2_circuit import (
    Layer2CircuitBlock,
    Layer2CircuitBlockInactive,
    Layer2CircuitBlockProvisioning,
)


class Layer2CircuitInactive(SubscriptionModel, is_base=True):
    """An inactive Layer 2 Circuit."""

    layer_2_circuit: Layer2CircuitBlockInactive


class Layer2CircuitProvisioning(Layer2CircuitInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A Layer 2 Circuit that is provisioning."""

    layer_2_circuit: Layer2CircuitBlockProvisioning


class Layer2Circuit(Layer2CircuitProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An active Layer 2 Circuit."""

    layer_2_circuit: Layer2CircuitBlock


class ImportedLayer2CircuitInactive(SubscriptionModel, is_base=True):
    """An imported, inactive Layer 2 Circuit."""

    layer_2_circuit: Layer2CircuitBlockInactive


class ImportedLayer2Circuit(
    ImportedLayer2CircuitInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported Layer 2 Circuit."""

    layer_2_circuit: Layer2CircuitBlock
